@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2014 Jan Nieuwenhuizen <janneke@gnu.org>
+  Copyright (C) 1997--2015 Jan Nieuwenhuizen <janneke@gnu.org>
   Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
@@ -140,12 +140,10 @@ const char Duration::type_p_name_[] = "ly:duration?";
 
 
 int
-Duration::print_smob (SCM s, SCM port, scm_print_state *)
+Duration::print_smob (SCM port, scm_print_state *)
 {
-  Duration *r = (Duration *) SCM_CELL_WORD_1 (s);
-
   scm_puts ("#<Duration ", port);
-  scm_display (ly_string2scm (r->to_string ()), port);
+  scm_display (ly_string2scm (to_string ()), port);
   scm_puts (" >", port);
 
   return 1;
