@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1997--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ LY_DEFINE (ly_engraver_make_grob, "ly:engraver-make-grob",
            "  @var{cause} should either be another grob"
            " or a music event.")
 {
-  LY_ASSERT_TYPE (Engraver::unsmob, engraver, 1);
+  LY_ASSERT_SMOB (Engraver, engraver, 1);
   LY_ASSERT_TYPE (ly_is_symbol, grob_name, 2);
   LY_ASSERT_TYPE (ly_is_grob_cause, cause, 3);
 
@@ -45,7 +45,7 @@ LY_DEFINE (ly_engraver_announce_end_grob, "ly:engraver-announce-end-grob",
            " @var{grob} being a grob.  @var{cause} should either"
            " be another grob or a music event.")
 {
-  LY_ASSERT_TYPE (Engraver::unsmob, engraver, 1);
+  LY_ASSERT_SMOB (Engraver, engraver, 1);
   LY_ASSERT_SMOB (Grob, grob, 2);
   LY_ASSERT_TYPE (ly_is_grob_cause, cause, 3);
 
