@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2004--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 2004--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,20 +19,26 @@
 
 #include "engraver.hh"
 #include "context.hh"
+#include "dispatcher.hh"
+#include "listener.hh"
 #include "warn.hh"
+#include "grob-properties.hh"
+#include "stream-event.hh"
+#include "translator.icc"
 
 class Grace_engraver : public Engraver
 {
-  void consider_change_grace_settings ();
-protected:
-  void start_translation_timestep ();
-  virtual void derived_mark () const;
-  virtual void initialize ();
-
-  TRANSLATOR_DECLARATIONS (Grace_engraver);
   Moment last_moment_;
   SCM grace_settings_;
-public:
+  void consider_change_grace_settings ();
+protected:
+  virtual void derived_mark () const;
+  virtual void process_music ();
+  virtual void start_translation_timestep ();
+  virtual void finalize ();
+
+  TRANSLATOR_DECLARATIONS (Grace_engraver);
+  DECLARE_LISTENER (grace_change);
 };
 
 Grace_engraver::Grace_engraver ()
@@ -41,32 +47,65 @@ Grace_engraver::Grace_engraver ()
   last_moment_ = Moment (Rational (-1, 1));
 }
 
+// The iterator should usually come before process_music
+IMPLEMENT_LISTENER (Grace_engraver, grace_change);
 void
-Grace_engraver::initialize ()
+Grace_engraver::grace_change (SCM)
 {
   consider_change_grace_settings ();
 }
 
+// if we are in grace time already on initialization, it is unlikely
+// that we'll receive a GraceChange event from the grace iterator yet,
+// so we want to start into grace mode anyway.  The downside is that
+// this will get us confused when given something like
+//
+// \new Voice { \oneVoice \grace { c''8 8 } g'1 }
+//
+// where \grace executes its actions already before \oneVoice, causing
+// different stem directions.
+
+void
+Grace_engraver::start_translation_timestep ()
+{
+  // Only on startup
+  if (last_moment_ == Rational (-1))
+    consider_change_grace_settings ();
+}
+
+// If the grace iterator has moved off to some other context, we might
+// not get to see the ChangeContext event.  In that case, we still
+// want to change into or out of grace mode settings as appropriate
+
+void
+Grace_engraver::process_music ()
+{
+  // We may have lost connection to the iterator in which case we
+  // still need to call consider_change_grace_settings in particular
+  // in order to get out of grace mode again
+  if (last_moment_ != now_mom ())
+    consider_change_grace_settings ();
+}
+
 void
 Grace_engraver::consider_change_grace_settings ()
 {
   Moment now = now_mom ();
-  if (last_moment_.grace_part_ && !now.grace_part_)
+
+  if (!now.grace_part_)
     {
       for (SCM s = grace_settings_; scm_is_pair (s); s = scm_cdr (s))
         {
-          SCM context = scm_caar (s);
-          SCM entry = scm_cdar (s);
-          SCM grob = scm_cadr (entry);
-          SCM sym = scm_caddr (entry);
+          SCM elt = scm_car (s);
+          SCM context = scm_car (elt);
+          SCM grob = scm_cadr (elt);
+          SCM cell = scm_cddr (elt);
 
-          execute_pushpop_property (Context::unsmob (context),
-                                    grob, sym, SCM_UNDEFINED);
+          Grob_property_info (Context::unsmob (context), grob).matched_pop (cell);
         }
-
       grace_settings_ = SCM_EOL;
     }
-  else if (!last_moment_.grace_part_ && now.grace_part_)
+  else if (!last_moment_.grace_part_)
     {
       SCM settings = get_property ("graceSettings");
 
@@ -79,24 +118,40 @@ Grace_engraver::consider_change_grace_settings ()
           SCM sym = scm_caddr (entry);
           SCM val = scm_cadr (scm_cddr (entry));
 
+          if (!scm_is_pair (sym))
+            sym = scm_list_1 (sym);
+
           Context *c = context ();
           while (c && !c->is_alias (context_name))
             c = c->get_parent_context ();
 
           if (c)
             {
-              execute_pushpop_property (c,
-                                        grob, sym, val);
+              SCM cell = Grob_property_info (c, grob).push (sym, val);
               grace_settings_
-                = scm_cons (scm_cons (c->self_scm (), entry), grace_settings_);
+                = scm_cons (scm_cons2 (c->self_scm (), grob, cell), grace_settings_);
             }
           else
             programming_error ("cannot find context from graceSettings: "
                                + ly_symbol2string (context_name));
         }
     }
+  if (last_moment_ == Rational (-1))
+    {
+      Dispatcher *d = context ()->event_source ();
+      d->add_listener (GET_LISTENER (grace_change), ly_symbol2scm ("GraceChange"));
+    }
+  last_moment_ = now;
+}
 
-  last_moment_ = now_mom ();
+void
+Grace_engraver::finalize ()
+{
+  if (last_moment_ != Rational (-1))
+    {
+      Dispatcher *d = context ()->event_source ();
+      d->remove_listener (GET_LISTENER (grace_change), ly_symbol2scm ("GraceChange"));
+    }
 }
 
 void
@@ -106,14 +161,6 @@ Grace_engraver::derived_mark () const
   Engraver::derived_mark ();
 }
 
-void
-Grace_engraver::start_translation_timestep ()
-{
-  consider_change_grace_settings ();
-}
-
-#include "translator.icc"
-
 ADD_TRANSLATOR (Grace_engraver,
                 /* doc */
                 "Set font size and other properties for grace notes.",
