@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2005--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 2005--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,12 +26,11 @@
 const char Grob::type_p_name_[] = "ly:grob?";
 
 SCM
-Grob::mark_smob (SCM ses)
+Grob::mark_smob ()
 {
-  ASSERT_LIVE_IS_ALLOWED (ses);
+  ASSERT_LIVE_IS_ALLOWED (self_scm ());
 
-  Grob *s = (Grob *) SCM_CELL_WORD_1 (ses);
-  scm_gc_mark (s->immutable_property_alist_);
+  scm_gc_mark (immutable_property_alist_);
 
   /* Do not mark the parents.  The pointers in the mutable
      property list form two tree like structures (one for X
@@ -40,23 +39,21 @@ Grob::mark_smob (SCM ses)
      between X and Y in an erratic manner, leading to much more
      recursion depth (and core dumps if we link to pthreads).  */
 
-  if (s->original ())
-    scm_gc_mark (s->original ()->self_scm ());
+  if (original ())
+    scm_gc_mark (original ()->self_scm ());
 
-  s->derived_mark ();
-  scm_gc_mark (s->object_alist_);
-  scm_gc_mark (s->interfaces_);
+  derived_mark ();
+  scm_gc_mark (object_alist_);
+  scm_gc_mark (interfaces_);
 
-  return s->mutable_property_alist_;
+  return mutable_property_alist_;
 }
 
 int
-Grob::print_smob (SCM s, SCM port, scm_print_state *)
+Grob::print_smob (SCM port, scm_print_state *)
 {
-  Grob *sc = (Grob *) SCM_CELL_WORD_1 (s);
-
   scm_puts ("#<Grob ", port);
-  scm_puts ((char *) sc->name ().c_str (), port);
+  scm_puts ((char *) name ().c_str (), port);
 
   /* Do not print properties, that is too much hassle.  */
   scm_puts (" >", port);
