@@ -44,21 +44,13 @@ void Listener::listen (SCM ev) const
 }
 
 SCM
-Listener::mark_smob (SCM sm)
+Listener::mark_smob ()
 {
-  Listener *me = (Listener *) SCM_CELL_WORD_1 (sm);
-  if (me->type_)
-    (me->type_->mark_callback) (me->target_);
+  if (type_)
+    (type_->mark_callback) (target_);
   return SCM_EOL;
 }
 
-int
-Listener::print_smob (SCM, SCM p, scm_print_state *)
-{
-  scm_puts ("#<Listener>", p);
-  return 1;
-}
-
 SCM
 Listener::equal_p (SCM a, SCM b)
 {
