@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1997--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   Jan Nieuwenhuizen <janneke@gnu.org>
 
@@ -466,6 +466,9 @@ Lookup::bezier_sandwich (Bezier top_curve, Bezier bottom_curve, Real thickness)
                              scm_from_double (top_curve.control_[2][Y_AXIS]),
                              scm_from_double (top_curve.control_[3][X_AXIS]),
                              scm_from_double (top_curve.control_[3][Y_AXIS]),
+                             ly_symbol2scm ("lineto"),
+                             scm_from_double (bottom_curve.control_[3][X_AXIS]),
+                             scm_from_double (bottom_curve.control_[3][Y_AXIS]),
                              ly_symbol2scm ("curveto"),
                              scm_from_double (bottom_curve.control_[2][X_AXIS]),
                              scm_from_double (bottom_curve.control_[2][Y_AXIS]),
