@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1998--2014 Jan Nieuwenhuizen <janneke@gnu.org>
+  Copyright (C) 1998--2015 Jan Nieuwenhuizen <janneke@gnu.org>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 #include "multi-measure-rest.hh"
 
 #include "directional-element-interface.hh"
-#include "duration.hh"
 #include "font-interface.hh"
 #include "international.hh"
 #include "lookup.hh"
@@ -132,7 +131,7 @@ Multi_measure_rest::height (SCM smob)
 }
 
 int
-calc_closest_duration_log (Grob *me, double duration, bool force_round_up, bool paranoid)
+calc_closest_duration_log (Grob *me, double duration, bool force_round_up)
 {
   bool round_up = force_round_up
                   || to_boolean (me->get_property ("round-up-to-longer-rest"));
@@ -147,9 +146,8 @@ calc_closest_duration_log (Grob *me, double duration, bool force_round_up, bool
   int maximum_usable_duration_log = 15;
 
   SCM duration_logs_list = me->get_property ("usable-duration-logs");
-  if (paranoid
-      && (to_boolean (scm_null_p (duration_logs_list))
-          || !to_boolean (scm_list_p (duration_logs_list))))
+  if (to_boolean (scm_null_p (duration_logs_list))
+      || !to_boolean (scm_list_p (duration_logs_list)))
     {
       warning (_ ("usable-duration-logs must be a non-empty list."
                   "  Falling back to whole rests."));
@@ -187,18 +185,17 @@ calc_closest_duration_log (Grob *me, double duration, bool force_round_up, bool
 }
 
 int
-calc_measure_duration_log (Grob *me, bool paranoid)
+calc_measure_duration_log (Grob *me)
 {
   SCM sml = dynamic_cast<Spanner *> (me)->get_bound (LEFT)
             ->get_property ("measure-length");
-  Rational ml = (Moment::unsmob (sml)) ? Moment::unsmob (sml)->main_part_
+  Rational ml = (Moment::is_smob (sml)) ? Moment::unsmob (sml)->main_part_
                 : Rational (1);
   double measure_duration = ml.Rational::to_double ();
   bool force_round_up = to_boolean (scm_list_p (scm_member (scm_cons (scm_from_int64 (ml.numerator ()),
                                                             scm_from_int64 (ml.denominator ())),
                                                             me->get_property ("round-up-exceptions"))));
-
-  return calc_closest_duration_log (me, measure_duration, force_round_up, paranoid);
+  return calc_closest_duration_log (me, measure_duration, force_round_up);
 }
 
 Stencil
@@ -221,7 +218,7 @@ Multi_measure_rest::symbol_stencil (Grob *me, Real space)
     }
 
   Font_metric *musfont = Font_interface::get_default_font (me);
-  int mdl = calc_measure_duration_log (me, true);
+  int mdl = calc_measure_duration_log (me);
 
   if (measure_count == 1)
     {
@@ -231,7 +228,7 @@ Multi_measure_rest::symbol_stencil (Grob *me, Real space)
           Real pos = Rest::staff_position_internal (me, mdl, dir);
           me->set_property ("staff-position", scm_from_double (pos));
         }
- 
+
       Stencil s = musfont->find_by_name (Rest::glyph_name (me, mdl, "", true, 0.0));
 
       s.translate_axis ((space - s.extent (X_AXIS).length ()) / 2, X_AXIS);
@@ -279,7 +276,7 @@ Multi_measure_rest::church_rest (Grob *me, Font_metric *musfont, int measure_cou
   SCM mols = SCM_EOL;
   int symbol_count = 0;
   Real symbols_width = 0.0;
-  double total_duration = measure_count * pow (2.0, -calc_measure_duration_log (me, true));
+  double total_duration = measure_count * pow (2.0, -calc_measure_duration_log (me));
 
   SCM staff_position = me->get_property ("staff-position");
 
@@ -299,7 +296,7 @@ Multi_measure_rest::church_rest (Grob *me, Font_metric *musfont, int measure_cou
 
   while (total_duration > 0)
     {
-      int dl = calc_closest_duration_log (me, total_duration, false, true);
+      int dl = calc_closest_duration_log (me, total_duration, false);
       double duration = pow (2.0, -dl);
 
       total_duration -= duration;
@@ -357,21 +354,26 @@ Multi_measure_rest::calculate_spacing_rods (Grob *me, Real length)
   Item *ri = sp->get_bound (RIGHT)->get_column ();
   Item *lb = li->find_prebroken_piece (RIGHT);
   Item *rb = ri->find_prebroken_piece (LEFT);
+
   Grob *spacing = Grob::unsmob (li->get_object ("spacing"));
   if (!spacing)
     spacing = Grob::unsmob (ri->get_object ("spacing"));
-  if (!spacing)
-    me->warning (_ ("Using naive multi measure rest spacing."));
-  else
+  if (spacing)
     {
       Spacing_options options;
       options.init_from_grob (me);
-      int dl = calc_measure_duration_log (me, false);
-      Duration dur = Duration (dl, 0);
-      Rational rat = dur.get_length ();
-      length = max (length, options.get_duration_space (rat));
+      Moment mlen = robust_scm2moment (li->get_property ("measure-length"),
+                                       Moment (1));
+      length += robust_scm2double (li->get_property ("full-measure-extra-space"), 0.0)
+                + options.get_duration_space (mlen.main_part_)
+                + (robust_scm2double (me->get_property ("space-increment"), 0.0)
+                   * log_2 (robust_scm2int (me->get_property ("measure-count"), 1)));
     }
 
+  length += 2 * robust_scm2double (me->get_property ("bound-padding"), 0.0);
+
+  Real minlen = robust_scm2double (me->get_property ("minimum-length"), 0.0);
+
   Item *combinations[4][2] = {{li, ri},
     {lb, ri},
     {li, rb},
@@ -390,12 +392,8 @@ Multi_measure_rest::calculate_spacing_rods (Grob *me, Real length)
       rod.item_drul_[LEFT] = li;
       rod.item_drul_[RIGHT] = ri;
 
-      rod.distance_ = Paper_column::minimum_distance (li, ri)
-                      + length
-                      + 2 * robust_scm2double (me->get_property ("bound-padding"), 1.0);
-
-      Real minlen = robust_scm2double (me->get_property ("minimum-length"), 0);
-      rod.distance_ = max (rod.distance_, minlen);
+      rod.distance_ = max (Paper_column::minimum_distance (li, ri) + length,
+                           minlen);
       rod.add_to_cols ();
     }
 }
@@ -438,6 +436,7 @@ ADD_INTERFACE (Multi_measure_rest,
                "minimum-length "
                "round-up-exceptions "
                "round-up-to-longer-rest "
+               "space-increment "
                "spacing-pair "
                "thick-thickness "
                "usable-duration-logs "
