@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1997--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -90,7 +90,7 @@ Moment
 Music::get_length () const
 {
   SCM lst = get_property ("length");
-  if (Moment::unsmob (lst))
+  if (Moment::is_smob (lst))
     return *Moment::unsmob (lst);
 
   if (ly_is_procedure (length_callback_))
@@ -329,9 +329,3 @@ Music::duration_length_callback (SCM m)
     mom = d->get_length ();
   return mom.smobbed_copy ();
 }
-
-Music *
-Music::unsmob (SCM m)
-{
-  return dynamic_cast<Music *> (Prob::unsmob (m));
-}
