@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2007--2014 Nicolas Sceaux <nicolas.sceaux@free.fr>
+  Copyright (C) 2007--2015 Nicolas Sceaux <nicolas.sceaux@free.fr>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@ Page_marker::Page_marker ()
 }
 
 Page_marker::Page_marker (Page_marker const &src)
+  : Smob<Page_marker> ()
 {
   symbol_ = src.symbol_;
   permission_ = src.permission_;
@@ -42,24 +43,14 @@ Page_marker::~Page_marker ()
 const char Page_marker::type_p_name_[] = "ly:page-marker?";
 
 SCM
-Page_marker::mark_smob (SCM smob)
+Page_marker::mark_smob ()
 {
-  Page_marker *pm = (Page_marker *) SCM_CELL_WORD_1 (smob);
-  scm_gc_mark (pm->symbol_);
-  scm_gc_mark (pm->permission_);
-  scm_gc_mark (pm->label_);
+  scm_gc_mark (symbol_);
+  scm_gc_mark (permission_);
+  scm_gc_mark (label_);
   return SCM_EOL;
 }
 
-int
-Page_marker::print_smob (SCM smob, SCM port, scm_print_state *)
-{
-  Page_marker *pm = (Page_marker *) SCM_CELL_WORD_1 (smob);
-  (void) pm;
-  scm_puts ("#<Page_marker>", port);
-  return 1;
-}
-
 SCM
 Page_marker::permission_symbol ()
 {
