@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1996--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1996--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -42,12 +42,6 @@ Paper_score::Paper_score (Output_def *layout)
   paper_systems_ = SCM_BOOL_F;
 }
 
-Paper_score::Paper_score (Paper_score const &s)
-  : Music_output (s)
-{
-  assert (false);
-}
-
 void
 Paper_score::derived_mark () const
 {
@@ -165,9 +159,3 @@ Paper_score::get_paper_systems ()
     }
   return paper_systems_;
 }
-
-Paper_score *
-Paper_score::unsmob (SCM x)
-{
-  return dynamic_cast<Paper_score *> (Music_output::unsmob (x));
-}
