@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1998--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1998--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -219,19 +219,18 @@ Pitch::down_to (int notename)
 }
 
 const char Pitch::type_p_name_[] = "ly:pitch?";
+
 SCM
-Pitch::mark_smob (SCM x)
+Pitch::mark_smob ()
 {
-  Pitch *p = (Pitch *) SCM_CELL_WORD_1 (x);
-  return p->scale_->self_scm ();
+  return scale_->self_scm ();
 }
 
 int
-Pitch::print_smob (SCM s, SCM port, scm_print_state *)
+Pitch::print_smob (SCM port, scm_print_state *)
 {
-  Pitch *r = (Pitch *) SCM_CELL_WORD_1 (s);
   scm_puts ("#<Pitch ", port);
-  scm_display (ly_string2scm (r->to_string ()), port);
+  scm_display (ly_string2scm (to_string ()), port);
   scm_puts (" >", port);
   return 1;
 }
