@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2004--2014 Jan Nieuwenhuizen <janneke@gnu.org>
+  Copyright (C) 2004--2015 Jan Nieuwenhuizen <janneke@gnu.org>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ Prob::equal_p (SCM sa, SCM sb)
           SCM aval = scm_cdar (aprop);
           SCM bval = scm_cdar (bprop);
           if (scm_caar (aprop) != scm_caar (bprop)
-              || (!(Input::unsmob (aval) && Input::unsmob (bval))
+              || (!(Input::is_smob (aval) && Input::is_smob (bval))
                   &&
                   !to_boolean (scm_equal_p (aval, bval))))
             return SCM_BOOL_F;
@@ -76,7 +76,7 @@ Prob::equal_p (SCM sa, SCM sb)
   return SCM_BOOL_T;
 }
 
-Prob::Prob (SCM type, SCM immutable_init)
+Prob::Prob (SCM type, SCM immutable_init) : Smob<Prob> ()
 {
   mutable_property_alist_ = SCM_EOL;
   immutable_property_alist_ = immutable_init;
@@ -89,6 +89,7 @@ Prob::~Prob ()
 }
 
 Prob::Prob (Prob const &src)
+  : Smob<Prob> ()
 {
   immutable_property_alist_ = src.immutable_property_alist_;
   mutable_property_alist_ = SCM_EOL;
@@ -113,28 +114,26 @@ Prob::derived_mark () const
 }
 
 SCM
-Prob::mark_smob (SCM smob)
+Prob::mark_smob ()
 {
-  ASSERT_LIVE_IS_ALLOWED (smob);
+  ASSERT_LIVE_IS_ALLOWED (self_scm ());
 
-  Prob *system = (Prob *) SCM_CELL_WORD_1 (smob);
-  scm_gc_mark (system->mutable_property_alist_);
-  system->derived_mark ();
+  scm_gc_mark (mutable_property_alist_);
+  derived_mark ();
 
-  return system->immutable_property_alist_;
+  return immutable_property_alist_;
 }
 
 int
-Prob::print_smob (SCM smob, SCM port, scm_print_state *)
+Prob::print_smob (SCM port, scm_print_state *)
 {
-  Prob *p = (Prob *) SCM_CELL_WORD_1 (smob);
   scm_puts ("#<", port);
   scm_puts ("Prob: ", port);
-  scm_display (p->type_, port);
+  scm_display (type_, port);
   scm_puts (" C++: ", port);
-  scm_puts (p->class_name (), port);
-  scm_display (p->mutable_property_alist_, port);
-  scm_display (p->immutable_property_alist_, port);
+  scm_puts (class_name (), port);
+  scm_display (mutable_property_alist_, port);
+  scm_display (immutable_property_alist_, port);
 
   scm_puts (" >\n", port);
   return 1;
