@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1997--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -62,27 +62,18 @@ Score::~Score ()
 const char Score::type_p_name_[] = "ly:score?";
 
 SCM
-Score::mark_smob (SCM s)
+Score::mark_smob ()
 {
-  Score *sc = (Score *) SCM_CELL_WORD_1 (s);
+  scm_gc_mark (header_);
+  for (vsize i = defs_.size (); i--;)
+    scm_gc_mark (defs_[i]->self_scm ());
 
-  scm_gc_mark (sc->header_);
-  for (vsize i = sc->defs_.size (); i--;)
-    scm_gc_mark (sc->defs_[i]->self_scm ());
-
-  scm_gc_mark (sc->input_location_);
-  return sc->music_;
-}
-
-int
-Score::print_smob (SCM, SCM p, scm_print_state *)
-{
-  scm_puts ("#<Score>", p);
-
-  return 1;
+  scm_gc_mark (input_location_);
+  return music_;
 }
 
 Score::Score (Score const &s)
+  : Smob<Score> ()
 {
   header_ = SCM_EOL;
   music_ = SCM_EOL;
@@ -164,7 +155,7 @@ Score::book_rendering (Output_def *layoutbook,
 void
 Score::set_music (SCM music)
 {
-  if (Music::unsmob (music_))
+  if (Music::is_smob (music_))
     {
       Music::unsmob (music)->origin ()->error (_ ("already have music in score"));
       Music::unsmob (music_)->origin ()->error (_ ("this is the previous music"));
