@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1999--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1999--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -153,11 +153,13 @@ ADD_INTERFACE (Script_interface,
                "avoid-slur "
                "direction-source "
                "positioning-done "
+               "script-column "
                "script-priority "
                "script-stencil "
                "side-relative-direction "
                "slur "
                "slur-padding "
                "toward-stem-shift "
+               "toward-stem-shift-in-column "
               );
 
