@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2014 Jan Nieuwenhuizen <janneke@gnu.org>
+  Copyright (C) 1997--2015 Jan Nieuwenhuizen <janneke@gnu.org>
   Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
@@ -362,20 +362,16 @@ Source_file::get_port () const
 const char Source_file::type_p_name_[] = "ly:source-file?";
 
 SCM
-Source_file::mark_smob (SCM smob)
+Source_file::mark_smob ()
 {
-  Source_file *sc = (Source_file *) SCM_CELL_WORD_1 (smob);
-
-  return sc->str_port_;
+  return str_port_;
 }
 
 int
-Source_file::print_smob (SCM smob, SCM port, scm_print_state *)
+Source_file::print_smob (SCM port, scm_print_state *)
 {
-  Source_file *sc = (Source_file *) SCM_CELL_WORD_1 (smob);
-
   scm_puts ("#<Source_file ", port);
-  scm_puts (sc->name_.c_str (), port);
+  scm_puts (name_.c_str (), port);
 
   /* Do not print properties, that is too much hassle.  */
   scm_puts (" >", port);
