@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2000--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 2000--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -86,7 +86,7 @@ Spaceable_grob::get_spring (Grob *this_col, Grob *next_col)
     {
       if (scm_is_pair (scm_car (s))
           && Grob::unsmob (scm_cdar (s)) == next_col
-          && Spring::unsmob (scm_caar (s)))
+          && Spring::is_smob (scm_caar (s)))
         spring = Spring::unsmob (scm_caar (s));
     }
 
