@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2005--2014 Erik Sandberg  <mandolaerik@gmail.com>
+  Copyright (C) 2005--2015 Erik Sandberg  <mandolaerik@gmail.com>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -86,8 +86,8 @@ Stream_event::make_transposable ()
       SCM prop = scm_car (entry);
       SCM val = scm_cdr (entry);
 
-      if ((Pitch::unsmob (val)
-           || (prop == ly_symbol2scm ("element") && Music::unsmob (val))
+      if ((Pitch::is_smob (val)
+           || (prop == ly_symbol2scm ("element") && Music::is_smob (val))
            || (prop == ly_symbol2scm ("elements") && scm_is_pair (val))
            || (prop == ly_symbol2scm ("pitch-alist") && scm_is_pair (val)))
           && scm_is_false (scm_assq (prop, mutable_property_alist_)))
@@ -113,9 +113,3 @@ Stream_event::undump (SCM data)
   obj->mutable_property_alist_ = scm_reverse (scm_cdr (data));
   return obj->unprotect ();
 }
-
-Stream_event *
-Stream_event::unsmob (SCM m)
-{
-  return dynamic_cast<Stream_event *> (Prob::unsmob (m));
-}
