@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1997--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -161,7 +161,7 @@ Tie::calc_direction (SCM smob)
   Grob *yparent = me->get_parent (Y_AXIS);
   if ((Tie_column::has_interface (yparent)
        || Semi_tie_column::has_interface (yparent))
-      && Grob_array::unsmob (yparent->get_object ("ties"))
+      && Grob_array::is_smob (yparent->get_object ("ties"))
       //      && Grob_array::unsmob (yparent->get_object ("ties"))->size () > 1
      )
     {
@@ -223,7 +223,7 @@ Tie::calc_control_points (SCM smob)
   Grob *yparent = me->get_parent (Y_AXIS);
   if ((Tie_column::has_interface (yparent)
        || Semi_tie_column::has_interface (yparent))
-      && Grob_array::unsmob (yparent->get_object ("ties")))
+      && Grob_array::is_smob (yparent->get_object ("ties")))
     {
       extract_grob_set (yparent, "ties", ties);
       if (me->original () && ties.size () == 1
@@ -300,7 +300,101 @@ Tie::print (SCM smob)
 }
 
 ADD_INTERFACE (Tie,
-               "A horizontal curve connecting two noteheads.",
+               "A tie - a horizontal curve connecting two noteheads.\n"
+               "\n"
+               "The following properties may be set in the @code{details}"
+               " list.\n"
+               "\n"
+               "@table @code\n"
+               "@item height-limit\n"
+               "The maximum height allowed for this tie.\n"
+               "@item ratio\n"
+               "Parameter for tie shape. The higher this number, the"
+               " quicker the slur attains its height-limit.\n"
+               "@item between-length-limit\n"
+               "This detail is currently unused.\n"
+               "@item wrong-direction-offset-penalty\n"
+               "Demerit for ties that are offset in the wrong"
+               " direction.\n"
+               "@item min-length\n"
+               "If the tie is shorter than this amount (in"
+               " staff-spaces) an increasingly large length penalty is"
+               " incurred.\n"
+               "@item min-length-penalty-factor\n"
+               "Demerit factor for tie lengths shorter than"
+               " @code{min-length}.\n"
+               "@item center-staff-line-clearance\n"
+               "If the center of the tie is closer to a staff line"
+               " than this amount, an increasingly large staff line"
+               " collision penalty is incurred.\n"
+               "@item tip-staff-line-clearance\n"
+               "If the tips of the tie are closer to a staff line"
+               " than this amount, an increasingly large staff line"
+               " collision penalty is incurred.\n"
+               "@item staff-line-collision-penalty\n"
+               "Demerit factor for ties whose tips or center come"
+               " close to staff lines.\n"
+               "@item dot-collision-clearance\n"
+               "If the tie comes closer to a dot than this amount, an"
+               " increasingly large dot collision penalty is incurred.\n"
+               "@item dot-collision-penalty\n"
+               "Demerit factor for ties which come close to dots.\n"
+               "@item note-head-gap\n"
+               "The distance (in staff-spaces) by which the ends of"
+               " the tie are offset horizontally from the center"
+               " line through the note head.\n"
+               "@item stem-gap\n"
+               "The distance (in staff-spaces) by which the ends of"
+               " the tie are offset horizontally from a stem which"
+               " is on the same side of the note head as the tie.\n"
+               "@item tie-column-monotonicity-penalty\n"
+               "Demerit if the y-position of this tie in the set of"
+               " ties being considered is less than the y-position"
+               " of the previous tie.\n"
+               "@item tie-tie-collision-distance\n"
+               "If this tie is closer than this amount to the previous"
+               " tie in the set being considered, an increasingly"
+               " large tie-tie collision penalty is incurred.\n"
+               "@item tie-tie-collision-penalty\n"
+               "Demerit factor for a tie in the set being considered"
+               " which is close to the previous one.\n"
+               "@item horizontal-distance-penalty-factor\n"
+               "Demerit factor for ties in the set being considered"
+               " which are horizontally distant from the note heads.\n"
+               "@item vertical-distance-penalty-factor\n"
+               "Demerit factor for ties in the set being considered"
+               " which are vertically distant from the note heads.\n"
+               "@item same-dir-as-stem-penalty\n"
+               "Demerit if tie is on the same side as a stem or on the"
+               " opposite side to the one specified.\n"
+               "@item intra-space-threshold\n"
+               "If the tie's height (in half staff-spaces) is less than"
+               " this it is positioned between two adjacent staff"
+               " lines; otherwise it is positioned to straddle a staff"
+               " line further from the note heads.\n"
+               "@item outer-tie-length-symmetry-penalty-factor\n"
+               "Demerit factor for ties horizontally positioned"
+               " unsymmetrically with respect to the two note heads.\n"
+               "@item outer-tie-vertical-distance-symmetry-penalty-factor\n"
+               "Demerit factor for ties vertically positioned"
+               " unsymmetrically with respect to the two note heads.\n"
+               "@item outer-tie-vertical-gap\n"
+               "Amount (in half staff-spaces) by which a tie is moved"
+               " away from the note heads if it is closer to either"
+               " of them than 0.25 half staff-spaces.\n"
+               "@item skyline-padding\n"
+               "Padding of the skylines around note heads in chords.\n"
+               "@item single-tie-region-size\n"
+               "The number of candidate ties to generate when only a"
+               " single tie is required.  Successive candidates differ"
+               " in their initial vertical position by half a"
+               " staff-space.\n"
+               "@item multi-tie-region-size\n"
+               "The number of variations that are tried for the"
+               " extremal ties in a chord.  Variations differ in their"
+               " initial vertical position by half a staff-space.\n"
+
+               "@end table\n",
 
                /* properties */
                "annotation "
